@@ -44,8 +44,9 @@ extern struct poptOption gconf_options[];
  * @subkey: key part below the gnome desktop settings directory
  *
  * Description:  Gets the full key name for a GNOME desktop specific
- * setting.  That is something that affects the whole desktop.  This
- * space should only be used by the gnome library and core applications.
+ * setting for a specific application. Those keys are used to store application-specific
+ * configuration, for example the history of a GnomeEntry. This
+ * config space should only be used by libraries.
  *
  * Returns:  A newly allocated string
  **/
@@ -54,11 +55,14 @@ gnome_gconf_get_gnome_libs_settings_relative (const gchar *subkey)
 {
         gchar *dir;
         gchar *key;
+        gchar *tmp;
 
+        tmp = gconf_escape_key (gnome_program_get_app_id (gnome_program_get()), -1);
+        
         dir = g_strconcat("/apps/gnome-settings/",
-                          gnome_program_get_app_id (gnome_program_get()),
+                          tmp,
                           NULL);
-
+        g_free (tmp);
         if (subkey && *subkey) {
                 key = gconf_concat_dir_and_key(dir, subkey);
                 g_free(dir);
@@ -76,7 +80,7 @@ gnome_gconf_get_gnome_libs_settings_relative (const gchar *subkey)
  * @subkey: key part below the gnome desktop settings directory
  *
  * Description:  Gets the full key name for an application specific
- * setting.  That is "/apps/<application_id>/<subkey>".
+ * setting.  That is "/apps/&lt;application_id&gt;/@subkey".
  *
  * Returns:  A newly allocated string
  **/
@@ -105,7 +109,7 @@ gnome_gconf_get_app_settings_relative (GnomeProgram *program, const gchar *subke
 }
 
 /**
- * gnome_gconf_lazy_init:
+ * gnome_gconf_lazy_init
  *
  * Description:  Internal libgnome/ui routine.  You never have
  * to do this from your code.  But all places in libgnome/ui
@@ -117,7 +121,6 @@ _gnome_gconf_lazy_init (void)
 {
 	/* Note this is the same as in libgnomeui/libgnomeui/gnome-gconf-ui.c,
 	 * keep this in sync (it's named gnomeui_gconf_lazy_init) */
-	char *argv [] = { "dummy", NULL };
         gchar *settings_dir;
 	GConfClient* client = NULL;
 	static gboolean initialized = FALSE;
@@ -127,8 +130,6 @@ _gnome_gconf_lazy_init (void)
 
 	initialized = TRUE;
 
-	gconf_init (1, argv, NULL);
-
         client = gconf_client_get_default ();
 
         gconf_client_add_dir (client,
@@ -143,8 +144,19 @@ _gnome_gconf_lazy_init (void)
 			      GCONF_CLIENT_PRELOAD_NONE,
 			      NULL);
         g_free (settings_dir);
+
+        /* Leak the GConfClient reference, we want to keep
+         * the client alive forever.
+         */
 }
 
+/**
+ * gnome_gconf_module_info_get
+ *
+ * An internal libgnome/ui routine. This will never be needed in public code.
+ *
+ * Returns: A #GnomeModuleInfo instance representing the GConf module.
+ */
 const GnomeModuleInfo *
 _gnome_gconf_module_info_get (void)
 {
